<blockquote class="inlineeditor"
      <?php foreach ($dataAttr as $item) : ?>
          data-<?php echo $item['key']; ?>="<?php echo $item['val']; ?>"
      <?php endforeach; ?>
      >{content}</blockquote>